aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--plugins/huawei/mm-broadband-bearer-huawei.c7
1 files changed, 5 insertions, 2 deletions
diff --git a/plugins/huawei/mm-broadband-bearer-huawei.c b/plugins/huawei/mm-broadband-bearer-huawei.c
index 364760fd..410f39e5 100644
--- a/plugins/huawei/mm-broadband-bearer-huawei.c
+++ b/plugins/huawei/mm-broadband-bearer-huawei.c
@@ -277,8 +277,11 @@ connect_3gpp_context_step (Connect3gppContext *ctx)
}
case CONNECT_3GPP_CONTEXT_STEP_DHCP:
- /* If too many retries (1s of wait between the retries), failed */
- if (ctx->check_count > 30) {
+ /* Wait for dial up timeout, retries for 120 times
+ * (1s between the retries, so it means 2 minutes).
+ * If too many retries, failed
+ */
+ if (ctx->check_count > 120) {
/* Clear context */
ctx->self->priv->connect_pending = NULL;
g_simple_async_result_set_error (ctx->result,